@@ -15,15 +15,19 @@
 #
 # author:  Steven Czerwinski <czerwin@scalyr.com>
 
-__author__ = 'czerwin@scalyr.com'
+from __future__ import unicode_literals
+from __future__ import absolute_import
+
+__author__ = "czerwin@scalyr.com"
 
 import unittest
 
 from scalyr_agent.json_lib import JsonArray, JsonObject
 from scalyr_agent.json_lib import JsonConversionException, JsonMissingFieldException
+from scalyr_agent.test_base import ScalyrTestCase
 
 
-class JsonObjectTests(unittest.TestCase):
+class JsonObjectTests(ScalyrTestCase):
     def test_constructor(self):
         x = JsonObject(foo=5, bar=True)
         self.assertEquals(x["foo"], 5)
@@ -64,7 +68,7 @@ class JsonObjectTests(unittest.TestCase):
         x = JsonObject(foo=5)
         self.assertEquals(x.get_int("foo"), 5)
 
-        x = JsonObject(foo=5L)
+        x = JsonObject(foo=5)
         self.assertEquals(x.get_int("foo"), 5)
 
         x = JsonObject(foo=5.21)
@@ -90,27 +94,27 @@ class JsonObjectTests(unittest.TestCase):
         self.assertRaises(JsonMissingFieldException, x.get_int, "none")
 
     def test_get_long(self):
-        x = JsonObject(foo=5L)
-        self.assertEquals(x.get_long("foo"), 5L)
+        x = JsonObject(foo=5)
+        self.assertEquals(x.get_long("foo"), 5)
 
-        x = JsonObject(foo=5L)
-        self.assertEquals(x.get_long("foo"), 5L)
+        x = JsonObject(foo=5)
+        self.assertEquals(x.get_long("foo"), 5)
 
         x = JsonObject(foo=5.21)
-        self.assertEquals(x.get_long("foo"), 5L)
+        self.assertEquals(x.get_long("foo"), 5)
 
         x = JsonObject(foo="5")
-        self.assertEquals(x.get_long("foo"), 5L)
+        self.assertEquals(x.get_long("foo"), 5)
 
         x = JsonObject(foo="5.2")
-        self.assertEquals(x.get_long("foo"), 5L)
+        self.assertEquals(x.get_long("foo"), 5)
 
         # Test that bad strings raise an exception
         x = JsonObject(foo="fhi3")
         self.assertRaises(JsonConversionException, x.get_long, "foo")
 
         # Test the default value is returned if field is missing.
-        self.assertEquals(x.get_long("none", default_value=5L), 5L)
+        self.assertEquals(x.get_long("none", default_value=5), 5)
 
         # Test returns none if missing.
         self.assertEquals(x.get_long("none", none_if_missing=True), None)
@@ -167,12 +171,10 @@ class JsonObjectTests(unittest.TestCase):
         self.assertEquals(x.get_json_object("none", none_if_missing=True), None)
 
         # Raise an exception when field is missing.
-        self.assertRaises(JsonMissingFieldException,
-                          y.get_json_object, "none")
+        self.assertRaises(JsonMissingFieldException, y.get_json_object, "none")
 
         # Raise an exception if field is not JsonObject
-        self.assertRaises(JsonConversionException,
-                          x.get_json_object, "foo")
+        self.assertRaises(JsonConversionException, x.get_json_object, "foo")
 
     def test_get_or_create_json_object(self):
         x = JsonObject(foo=5, bar=True)
@@ -185,40 +187,56 @@ class JsonObjectTests(unittest.TestCase):
         JsonObject(foo=5, bar=True)
 
     def test_equality(self):
-        x = JsonObject(foo='a', bar=10)
-        y = JsonObject(foo='a', bar=10)
-        z = JsonObject(foo='a', bar=10, zar=True)
+        x = JsonObject(foo="a", bar=10)
+        y = JsonObject(foo="a", bar=10)
+        z = JsonObject(foo="a", bar=10, zar=True)
 
         self.assertEquals(x, y)
         self.assertNotEquals(x, z)
         self.assertNotEquals(y, z)
 
     def test_keys(self):
-        x = JsonObject(foo='a', bar=10)
+        x = JsonObject(foo="a", bar=10)
 
-        keys = x.keys()
+        keys = list(x.keys())
         self.assertEquals(len(keys), 2)
-        self.assertTrue(keys[0] == 'foo' or keys[0] == 'bar')
-        self.assertTrue(keys[1] == 'foo' or keys[1] == 'bar')
+        self.assertTrue(keys[0] == "foo" or keys[0] == "bar")
+        self.assertTrue(keys[1] == "foo" or keys[1] == "bar")
 
     def test_contains(self):
-        x = JsonObject(foo='a', bar=10)
-        self.assertTrue('foo' in x)
-        self.assertFalse('baz' in x)
+        x = JsonObject(foo="a", bar=10)
+        self.assertTrue("foo" in x)
+        self.assertFalse("baz" in x)
 
     def test_iter(self):
-        x = JsonObject(foo='a', bar=10)
+        x = JsonObject(foo="a", bar=10)
 
         keys = []
         for key in x:
             keys.append(key)
 
         self.assertEquals(len(keys), 2)
-        self.assertTrue('foo' in keys)
-        self.assertTrue('bar' in keys)
+        self.assertTrue("foo" in keys)
+        self.assertTrue("bar" in keys)
+
+    def test_to_dict(self):
+        x = JsonObject(foo="a", bar=10)
+        self.assertEquals(dict(foo="a", bar=10), x.to_dict())
+
+        x = JsonObject(foo=JsonObject(bee=1), bar=10)
+        self.assertEquals(dict(foo=dict(bee=1), bar=10), x.to_dict())
+
+        x = JsonObject(foo=dict(bee=1, boo=JsonObject(hi=True)), bar=10)
+        self.assertEquals(dict(foo=dict(bee=1, boo=dict(hi=True)), bar=10), x.to_dict())
+
+        x = JsonObject(foo=JsonArray(1, 2, 3), bar=10)
+        self.assertEquals(dict(foo=[1, 2, 3], bar=10), x.to_dict())
+
+        x = JsonObject(foo=[1, 2, JsonObject(foo=5)], bar=10)
+        self.assertEquals(dict(foo=[1, 2, dict(foo=5)], bar=10), x.to_dict())
 
 
-class JsonArrayTests(unittest.TestCase):
+class JsonArrayTests(ScalyrTestCase):
     def test_constructor(self):
         x = JsonArray("hi", True)
         self.assertEquals(len(x), 2)
@@ -230,8 +248,7 @@ class JsonArrayTests(unittest.TestCase):
         x = JsonArray(y, "Not an object")
         self.assertEquals(len(x), 2)
         self.assertTrue(x.get_json_object(0) == y)
-        self.assertRaises(JsonConversionException,
-                          x.get_json_object, 1)
+        self.assertRaises(JsonConversionException, x.get_json_object, 1)
 
     def test_iter(self):
         y = JsonObject(foo=True)
@@ -257,11 +274,11 @@ class JsonArrayTests(unittest.TestCase):
         self.assertTrue(x[0] == z[0])
 
     def test_set_item(self):
-        x = JsonArray('bye', 3)
-        x[0] = 'hi'
-        self.assertEquals(x[0], 'hi')
+        x = JsonArray("bye", 3)
+        x[0] = "hi"
+        self.assertEquals(x[0], "hi")
 
-        self.assertRaises(IndexError, x.__setitem__, 5, 'foo')
+        self.assertRaises(IndexError, x.__setitem__, 5, "foo")
 
     def test_equals(self):
         x = JsonArray(1, 2)
@@ -276,5 +293,6 @@ class JsonArrayTests(unittest.TestCase):
 def main():
     unittest.main()
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     main()
